Uses of Interface
io.microsphere.lang.Prioritized
-
-
Uses of Prioritized in io.microsphere.classloading
Subinterfaces of Prioritized in io.microsphere.classloading Modifier and Type Interface Description interfaceArtifactResourceResolverArtifactResourceResolverinterface is responsible for resolving resources related to anArtifact.interfaceURLClassPathHandleA strategy interface for handling URL Class-Path entries in aClassLoader.Classes in io.microsphere.classloading that implement Prioritized Modifier and Type Class Description classAbstractArtifactResourceResolverAn abstract base class for implementingArtifactResourceResolver.classAbstractURLClassPathHandleAbstract implementation ofURLClassPathHandlethat provides a base for handling URL Class-Path entries.classArchiveFileArtifactResourceResolverA concrete implementation ofArtifactResourceResolverthat resolves artifacts based on archive files.classClassicURLClassPathHandleClassicURLClassPathHandleforsun.misc.URLClassPathsince JDK 1 to 8classManifestArtifactResourceResolverArtifactResourceResolverimplementation that reads artifact metadata from JAR manifest files.classMavenArtifactResourceResolverA resolver implementation for Maven artifact metadata, extracting information from Maven POM properties files.classModernURLClassPathHandleModernURLClassPathHandleforjdk.internal.loader.URLClassPathsince JDK 9classNoOpURLClassPathHandleNo-OperationURLClassPathHandleclassServiceLoadingURLClassPathHandleURLClassPathHandleimplementation based on the Service Loading mechanismclassStreamArtifactResourceResolverAn abstract base class for implementingArtifactResourceResolverthat provides a skeletal implementation to resolve artifact resources from either a streamable resource (like a URL) or an archive file (like a JAR). -
Uses of Prioritized in io.microsphere.convert
Subinterfaces of Prioritized in io.microsphere.convert Modifier and Type Interface Description interfaceConverter<S,T>A functional interface that defines a strategy for converting values from one type (S) to another type (T).interfaceStringConverter<T>A class to covertStringto the target-typed valueClasses in io.microsphere.convert that implement Prioritized Modifier and Type Class Description classAbstractConverter<S,T>An abstract base class for implementing theConverterinterface.classByteArrayToObjectConverterThe class coverts thebyte arrayobject to be aObjectinstance .classMapToPropertiesConverterclassNumberToByteConverterclassNumberToCharacterConverterclassNumberToDoubleConverterclassNumberToFloatConverterclassNumberToIntegerConverterclassNumberToLongConverterclassNumberToShortConverterclassObjectToBooleanConverterclassObjectToByteArrayConverterThe class coverts theObjectinstance to bebyte arrayobject.classObjectToByteConverterclassObjectToCharacterConverterclassObjectToDoubleConverterclassObjectToFloatConverterclassObjectToIntegerConverterclassObjectToLongConverterclassObjectToOptionalConverterThe class to convertObjecttoOptionalclassObjectToShortConverterclassObjectToStringConverterclassPropertiesToStringConverterclassStringToBooleanConverterThe class to convertStringtoBooleanclassStringToByteConverterThe class to convertStringtoByteclassStringToCharacterConverterThe class to convertStringtoCharacterclassStringToCharArrayConverterThe class to convertStringtochar[]classStringToClassConverterThe class to convertStringtoClassclassStringToDoubleConverterThe class to convertStringtoDoubleclassStringToDurationConverterThe class to convertStringtoDurationclassStringToFloatConverterThe class to convertStringtoFloatclassStringToInputStreamConverterThe class to convertStringtoInputStreamclassStringToIntegerConverterThe class to convertStringtoIntegerclassStringToLongConverterThe class to convertStringtoLongclassStringToShortConverterThe class to convertStringtoShortclassStringToStringConverterThe class to convertStringtoString -
Uses of Prioritized in io.microsphere.convert.multiple
Subinterfaces of Prioritized in io.microsphere.convert.multiple Modifier and Type Interface Description interfaceMultiValueConverter<S>An interface to convert the source-typed value to multiple value, e.g , Java array,Collectionor sub-interfacesinterfaceStringToMultiValueConverterThe class to convertStringto multiple value objectClasses in io.microsphere.convert.multiple that implement Prioritized Modifier and Type Class Description classStringToArrayConverterThe class to convertStringto array-type objectclassStringToBlockingDequeConverterThe class to convertStringtoBlockingDeque-based valueclassStringToBlockingQueueConverterThe class to convertStringtoBlockingDeque-based valueclassStringToCollectionConverterThe class to convertStringtoCollection-based valueclassStringToDequeConverterThe class to convertStringtoDeque-based valueclassStringToIterableConverter<T extends java.lang.Iterable>The class to convertStringtoIterable-based valueclassStringToListConverterThe class to convertStringtoList-based valueclassStringToNavigableSetConverterThe class to convertStringtoSortedSet-based valueclassStringToQueueConverterThe class to convertStringtoDeque-based valueclassStringToSetConverterThe class to convertStringtoSet-based valueclassStringToSortedSetConverterThe class to convertStringtoSortedSet-based valueclassStringToTransferQueueConverterThe class to convertStringtoTransferQueue-based value -
Uses of Prioritized in io.microsphere.event
Subinterfaces of Prioritized in io.microsphere.event Modifier and Type Interface Description interfaceConditionalEventListener<E extends Event>A conditional extension of theEventListenerinterface that allows filtering events before handling.interfaceEventListener<E extends Event>Classes in io.microsphere.event that implement Prioritized Modifier and Type Class Description classGenericEventListenerA generic implementation of theEventListenerinterface that supports multiple event handling methods. -
Uses of Prioritized in io.microsphere.io.event
Subinterfaces of Prioritized in io.microsphere.io.event Modifier and Type Interface Description interfaceFileChangedListenerA listener interface for receiving file change events.Classes in io.microsphere.io.event that implement Prioritized Modifier and Type Class Description classLoggingFileChangedListenerAFileChangedListenerimplementation that logs file change events at the debug level. -
Uses of Prioritized in io.microsphere.lang
Methods in io.microsphere.lang with parameters of type Prioritized Modifier and Type Method Description default intPrioritized. compareTo(Prioritized that) -
Uses of Prioritized in io.microsphere.logging
Classes in io.microsphere.logging that implement Prioritized Modifier and Type Class Description classACLLoggerFactoryLoggerFactoryimplementation for Apache Commons Logging (ACL).classJDKLoggerFactoryALoggerFactoryimplementation that creates and manages instances of JDK logging (Logger).classLoggerFactoryTheLoggerFactoryserves as an abstract base class for creating and managing instances of theLoggertype.classNoOpLoggerFactoryALoggerFactoryimplementation that provides instances ofNoOpLogger, which perform no operations for logging calls.classSfl4jLoggerFactoryTheLoggerFactoryimplementation for creating and managing SLF4J-basedLoggerinstances. -
Uses of Prioritized in io.microsphere.metadata
Subinterfaces of Prioritized in io.microsphere.metadata Modifier and Type Interface Description interfaceConfigurationPropertyGeneratorConfigurationPropertyGeneratorinterface can be implemented by objects that generate string representations (e.g., JSON, XML, Properties) ofConfigurationProperty.interfaceConfigurationPropertyLoaderThe Java SPI of the loader ofConfigurationPropertythat will beloaded byMicrosphere Annotation Processor module.interfaceConfigurationPropertyReaderThe SPI to read the list ofconfiguration propertiesfrom various sources.Classes in io.microsphere.metadata that implement Prioritized Modifier and Type Class Description classAdditionalMetadataResourceConfigurationPropertyLoaderConfigurationPropertyLoaderclass to load the additional configuration properties metadata fromresource location.classClassPathResourceConfigurationPropertyLoaderConfigurationPropertyLoaderto load the target Class-Path resource.classDefaultConfigurationPropertyGeneratorThe default implementation class ofConfigurationPropertyGenerator.classDefaultConfigurationPropertyReaderConfigurationPropertyReaderbased on JSON content.classMetadataResourceConfigurationPropertyLoaderConfigurationPropertyLoaderclass to load the configuration properties metadata fromresource location.classReflectiveConfigurationPropertyGeneratorConfigurationPropertyGeneratorclass based on Java Reflection API -
Uses of Prioritized in io.microsphere.process
Subinterfaces of Prioritized in io.microsphere.process Modifier and Type Interface Description interfaceProcessIdResolverA strategy interface for resolving the current process ID.Classes in io.microsphere.process that implement Prioritized Modifier and Type Class Description classClassicProcessIdResolverAProcessIdResolverimplementation for classic JDK versions (5 - 8).classModernProcessIdResolverAProcessIdResolverimplementation for modern JDKs (Java 9+).classVirtualMachineProcessIdResolverAProcessIdResolverimplementation for retrieving the process ID using the SUN JVM internal APIs.
-