Class MBeanDescribableBuilder<B extends MBeanDescribableBuilder>

  • Type Parameters:
    B - the builder class
    Direct Known Subclasses:
    MBeanFeatureInfoBuilder, MBeanInfoBuilder

    public abstract class MBeanDescribableBuilder<B extends MBeanDescribableBuilder>
    extends java.lang.Object
    MBean Describable Builder
    Since:
    1.0.0
    Author:
    Mercy
    See Also:
    MBeanFeatureInfo
    • Field Summary

      Fields 
      Modifier and Type Field Description
      protected java.lang.String description
      The human-readable description.
      protected javax.management.Descriptor descriptor
      This field can be null, which is equivalent to an empty Descriptor.
    • Method Summary

      All Methods Instance Methods Abstract Methods Concrete Methods 
      Modifier and Type Method Description
      abstract <I extends javax.management.DescriptorRead>
      I
      build()  
      B description​(java.lang.String description)  
      B descriptor​(javax.management.Descriptor descriptor)  
      • Methods inherited from class java.lang.Object

        clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
    • Field Detail

      • description

        @Nullable
        protected java.lang.String description
        The human-readable description.
      • descriptor

        @Nullable
        protected javax.management.Descriptor descriptor
        This field can be null, which is equivalent to an empty Descriptor.
    • Method Detail

      • description

        public B description​(java.lang.String description)
      • descriptor

        public B descriptor​(javax.management.Descriptor descriptor)
      • build

        public abstract <I extends javax.management.DescriptorRead> I build()