Uses of Interface
io.microsphere.metadata.ConfigurationPropertyLoader
-
Packages that use ConfigurationPropertyLoader Package Description io.microsphere.metadata -
-
Uses of ConfigurationPropertyLoader in io.microsphere.metadata
Classes in io.microsphere.metadata that implement ConfigurationPropertyLoader Modifier and Type Class Description classAdditionalMetadataResourceConfigurationPropertyLoaderConfigurationPropertyLoaderclass to load the additional configuration properties metadata fromresource location.classClassPathResourceConfigurationPropertyLoaderConfigurationPropertyLoaderto load the target Class-Path resource.classMetadataResourceConfigurationPropertyLoaderConfigurationPropertyLoaderclass to load the configuration properties metadata fromresource location.
-