Package io.microsphere.util
Class Assert
- java.lang.Object
-
- io.microsphere.util.BaseUtils
-
- io.microsphere.util.Assert
-
-
Constructor Summary
Constructors Constructor Description Assert()
-
Method Summary
All Methods Static Methods Concrete Methods Modifier and Type Method Description static voidassertNoNullElements(java.lang.Iterable<?> elements, java.lang.String message)Assert that a elements contains nonullelements.static voidassertNoNullElements(java.lang.Iterable<?> elements, java.util.function.Supplier<java.lang.String> messageSupplier)Assert that a elements contains nonullelements.static voidassertNoNullElements(java.lang.Object[] array, java.lang.String message)Assert that an array contains nonullelements.static voidassertNoNullElements(java.lang.Object[] array, java.util.function.Supplier<java.lang.String> messageSupplier)Assert that an array contains nonullelements.static voidassertNotBlank(java.lang.String text, java.lang.String message)Assert that a string is not blank.static voidassertNotBlank(java.lang.String text, java.util.function.Supplier<java.lang.String> messageSupplier)Assert that a string is not blank.static voidassertNotEmpty(java.lang.Object[] array, java.lang.String message)Assert that an array contains elements; that is, it must not benulland must contain at least one element.static voidassertNotEmpty(java.lang.Object[] array, java.util.function.Supplier<java.lang.String> messageSupplier)Assert that an array contains elements; that is, it must not benulland must contain at least one element.static voidassertNotEmpty(java.lang.String text, java.lang.String message)Assert that a string is not empty ("").static voidassertNotEmpty(java.lang.String text, java.util.function.Supplier<java.lang.String> messageSupplier)Assert that a string is not empty ("").static voidassertNotEmpty(java.util.Collection<?> collection, java.lang.String message)Assert that a collection contains elements; that is, it must not benulland must contain at least one element.static voidassertNotEmpty(java.util.Collection<?> collection, java.util.function.Supplier<java.lang.String> messageSupplier)Assert that a collection contains elements; that is, it must not benulland must contain at least one element.static voidassertNotEmpty(java.util.Map<?,?> map, java.lang.String message)Assert that a Map contains entries; that is, it must not benulland must contain at least one entry.static voidassertNotEmpty(java.util.Map<?,?> map, java.util.function.Supplier<java.lang.String> messageSupplier)Assert that a Map contains entries; that is, it must not benulland must contain at least one entry.static voidassertNotNull(java.lang.Object object, java.lang.String message)Assert that an object is notnull.static voidassertNotNull(java.lang.Object object, java.util.function.Supplier<java.lang.String> messageSupplier)Assert that an object is notnull.static voidassertNull(java.lang.Object object, java.lang.String message)Assert that an object isnull.static voidassertNull(java.lang.Object object, java.util.function.Supplier<java.lang.String> messageSupplier)Assert that an object isnull.static voidassertTrue(boolean expression, java.lang.String message)Assert a boolean expression, throwing anIllegalArgumentExceptionif the expression evaluates tofalse.static voidassertTrue(boolean expression, java.util.function.Supplier<java.lang.String> messageSupplier)Assert a boolean expression, throwing anIllegalArgumentExceptionif the expression evaluates tofalse.
-
-
-
Method Detail
-
assertTrue
public static void assertTrue(boolean expression, java.lang.String message)Assert a boolean expression, throwing anIllegalArgumentExceptionif the expression evaluates tofalse.assertTrue(i > 0, "The value must be greater than zero");
- Parameters:
expression- a boolean expressionmessage- the exception message to use if the assertion fails- Throws:
java.lang.IllegalArgumentException- ifexpressionisfalse
-
assertTrue
public static void assertTrue(boolean expression, java.util.function.Supplier<java.lang.String> messageSupplier)Assert a boolean expression, throwing anIllegalArgumentExceptionif the expression evaluates tofalse.assertTrue(i > 0, () -> "The value '" + i + "' must be greater than zero");
- Parameters:
expression- a boolean expressionmessageSupplier- a supplier for the exception message to use if the assertion fails- Throws:
java.lang.IllegalArgumentException- ifexpressionisfalse
-
assertNull
public static void assertNull(@Nullable java.lang.Object object, java.lang.String message)Assert that an object isnull.assertNull(value, "The value must be null");
- Parameters:
object- the object to checkmessage- the exception message to use if the assertion fails- Throws:
java.lang.IllegalArgumentException- if the object is notnull
-
assertNull
public static void assertNull(@Nullable java.lang.Object object, java.util.function.Supplier<java.lang.String> messageSupplier)Assert that an object isnull.assertNull(value, () -> "The value '" + value + "' must be null");
- Parameters:
object- the object to checkmessageSupplier- a supplier for the exception message to use if the assertion fails- Throws:
java.lang.IllegalArgumentException- if the object is notnull
-
assertNotNull
public static void assertNotNull(@Nullable java.lang.Object object, java.lang.String message)Assert that an object is notnull.assertNotNull(clazz, "The class must not be null");
- Parameters:
object- the object to checkmessage- the exception message to use if the assertion fails- Throws:
java.lang.IllegalArgumentException- if the object isnull
-
assertNotNull
public static void assertNotNull(@Nullable java.lang.Object object, java.util.function.Supplier<java.lang.String> messageSupplier)Assert that an object is notnull.assertNotNull(entity.getId(), () -> "ID for entity " + entity.getName() + " must not be null");
- Parameters:
object- the object to checkmessageSupplier- a supplier for the exception message to use if the assertion fails- Throws:
java.lang.IllegalArgumentException- if the object isnull
-
assertNotEmpty
public static void assertNotEmpty(@Nullable java.lang.String text, java.lang.String message)Assert that a string is not empty ("").assertNotEmpty(entity.getName(), "Name for entity " + entity.getName() + " must not be empty");
- Parameters:
text- the text to checkmessage- the exception message to use if the assertion fails
-
assertNotEmpty
public static void assertNotEmpty(@Nullable java.lang.String text, java.util.function.Supplier<java.lang.String> messageSupplier)Assert that a string is not empty ("").assertNotEmpty(entity.getName(), () -> "Name for entity " + entity.getName() + " must not be empty");
- Parameters:
text- the text to checkmessageSupplier- a supplier for the exception message to use if the assertion fails
-
assertNotBlank
public static void assertNotBlank(@Nullable java.lang.String text, java.lang.String message)Assert that a string is not blank.assertNotBlank(entity.getName(), "Name for entity " + entity.getName() + " must not be blank");
- Parameters:
text- the text to checkmessage- the exception message to use if the assertion fails
-
assertNotBlank
public static void assertNotBlank(@Nullable java.lang.String text, java.util.function.Supplier<java.lang.String> messageSupplier)Assert that a string is not blank.assertNotBlank(entity.getName(), () -> "Name for entity " + entity.getName() + " must not be blank");
- Parameters:
text- the text to checkmessageSupplier- a supplier for the exception message to use if the assertion fails
-
assertNotEmpty
public static void assertNotEmpty(@Nullable java.lang.Object[] array, java.lang.String message)Assert that an array contains elements; that is, it must not benulland must contain at least one element.assertNotEmpty(array, "The array must contain elements");
- Parameters:
array- the array to checkmessage- the exception message to use if the assertion fails- Throws:
java.lang.IllegalArgumentException- if the object array isnullor contains no elements
-
assertNotEmpty
public static void assertNotEmpty(@Nullable java.lang.Object[] array, java.util.function.Supplier<java.lang.String> messageSupplier)Assert that an array contains elements; that is, it must not benulland must contain at least one element.assertNotEmpty(array, () -> "The " + arrayType + " array must contain elements");
- Parameters:
array- the array to checkmessageSupplier- a supplier for the exception message to use if the assertion fails- Throws:
java.lang.IllegalArgumentException- if the object array isnullor contains no elements
-
assertNotEmpty
public static void assertNotEmpty(@Nullable java.util.Collection<?> collection, java.lang.String message)Assert that a collection contains elements; that is, it must not benulland must contain at least one element.assertNotEmpty(collection, "Collection must contain elements");
- Parameters:
collection- the collection to checkmessage- the exception message to use if the assertion fails- Throws:
java.lang.IllegalArgumentException- if the collection isnullor contains no elements
-
assertNotEmpty
public static void assertNotEmpty(@Nullable java.util.Collection<?> collection, java.util.function.Supplier<java.lang.String> messageSupplier)Assert that a collection contains elements; that is, it must not benulland must contain at least one element.assertNotEmpty(collection, () -> "The " + collectionType + " collection must contain elements");
- Parameters:
collection- the collection to checkmessageSupplier- a supplier for the exception message to use if the assertion fails- Throws:
java.lang.IllegalArgumentException- if the collection isnullor contains no elements
-
assertNotEmpty
public static void assertNotEmpty(@Nullable java.util.Map<?,?> map, java.lang.String message)Assert that a Map contains entries; that is, it must not benulland must contain at least one entry.assertNotEmpty(map, "Map must contain entries");
- Parameters:
map- the map to checkmessage- the exception message to use if the assertion fails- Throws:
java.lang.IllegalArgumentException- if the map isnullor contains no entries
-
assertNotEmpty
public static void assertNotEmpty(@Nullable java.util.Map<?,?> map, java.util.function.Supplier<java.lang.String> messageSupplier)Assert that a Map contains entries; that is, it must not benulland must contain at least one entry.assertNotEmpty(map, () -> "The " + mapType + " map must contain entries");
- Parameters:
map- the map to checkmessageSupplier- a supplier for the exception message to use if the assertion fails- Throws:
java.lang.IllegalArgumentException- if the map isnullor contains no entries
-
assertNoNullElements
public static void assertNoNullElements(@Nullable java.lang.Object[] array, java.lang.String message)Assert that an array contains nonullelements.Note: Does not complain if the array is empty!
assertNoNullElements(array, "The array must contain non-null elements");
- Parameters:
array- the array to checkmessage- the exception message to use if the assertion fails- Throws:
java.lang.IllegalArgumentException- if the object array contains anullelement
-
assertNoNullElements
public static void assertNoNullElements(@Nullable java.lang.Object[] array, java.util.function.Supplier<java.lang.String> messageSupplier)Assert that an array contains nonullelements.Note: Does not complain if the array is empty!
assertNoNullElements(array, () -> "The " + arrayType + " array must contain non-null elements");
- Parameters:
array- the array to checkmessageSupplier- a supplier for the exception message to use if the assertion fails- Throws:
java.lang.IllegalArgumentException- if the object array contains anullelement
-
assertNoNullElements
public static void assertNoNullElements(@Nullable java.lang.Iterable<?> elements, java.lang.String message)Assert that a elements contains nonullelements.Note: Does not complain if the elements is empty!
assertNoNullElements(elements, "Elements must contain non-null elements");
- Parameters:
elements- the elements to checkmessage- the exception message to use if the assertion fails- Throws:
java.lang.IllegalArgumentException- if the elements contains anullelement
-
assertNoNullElements
public static void assertNoNullElements(@Nullable java.lang.Iterable<?> elements, java.util.function.Supplier<java.lang.String> messageSupplier)Assert that a elements contains nonullelements.Note: Does not complain if the elements is empty!
assertNoNullElements(elements, () -> "Collection " + collectionName + " must contain non-null elements");
- Parameters:
elements- the elements to checkmessageSupplier- a supplier for the exception message to use if the assertion fails- Throws:
java.lang.IllegalArgumentException- if the elements contains anullelement
-
-