<R> Configurer<R> |
Configurer.as(java.util.function.Function<T,R> function) |
Converts the current value to a new type using the given Function.
|
Configurer<T> |
Configurer.compare(java.util.function.Supplier<T> comparedValueSupplier) |
Compares the current value with a value resolved from the given Supplier.
|
Configurer<T> |
Configurer.compare(T comparedValue) |
Compares the current value with the given value.
|
static <T> Configurer<T> |
Configurer.configure(java.lang.String name) |
Creates a new Configurer with the specified name and no initial value.
|
static <T> Configurer<T> |
Configurer.configure(java.lang.String name,
java.util.function.Supplier<T> valueSupplier) |
Creates a new Configurer with the specified name and a value eagerly resolved
from the given Supplier.
|
static <T> Configurer<T> |
Configurer.configure(java.lang.String name,
T value) |
Creates a new Configurer with the specified name and initial value.
|
static <T> Configurer<T> |
Configurer.configure(java.util.function.Supplier<T> valueSupplier) |
Creates a new unnamed Configurer with a value eagerly resolved from the given
Supplier.
|
static <T> Configurer<T> |
Configurer.configure(T value) |
Creates a new unnamed Configurer with the specified value.
|
Configurer<T> |
Configurer.on(java.util.function.Predicate<? super T> predicate) |
Filters the current value using the given Predicate.
|
<T> Configurer<T> |
Configurer.value(java.util.function.Supplier<T> valueSupplier) |
Creates a new Configurer with the same name and a value eagerly resolved
from the given Supplier, replacing the current configuration value.
|
<T> Configurer<T> |
Configurer.value(T value) |
Creates a new Configurer with the same name and the specified value,
replacing the current configuration value.
|