<R> Functional<R> |
Functional.as(java.util.function.Function<V,R> function) |
Transforms the current value using the given Function and returns a new Functional
wrapping the result.
|
static <V> Functional<V> |
Functional.of(java.lang.String name,
java.util.function.Supplier<V> valueSupplier) |
Creates a named Functional instance whose value is obtained from the given
Supplier.
|
static <V> Functional<V> |
Functional.of(java.lang.String name,
V value) |
Creates a named Functional instance wrapping the given value.
|
Functional<V> |
Functional.on(java.util.function.Predicate<? super V> predicate) |
Tests the current value against the given Predicate.
|
static <V> Functional<V> |
Functional.value(java.util.function.Supplier<V> valueSupplier) |
Creates an unnamed Functional instance whose value is obtained from the given
Supplier.
|
static <V> Functional<V> |
Functional.value(V value) |
Creates an unnamed Functional instance wrapping the given value.
|