Uses of Class
io.microsphere.util.StopWatch.Task
-
Packages that use StopWatch.Task Package Description io.microsphere.util -
-
Uses of StopWatch.Task in io.microsphere.util
Methods in io.microsphere.util that return StopWatch.Task Modifier and Type Method Description StopWatch.TaskStopWatch. getCurrentTask()Returns the most recently started running task without removing it from the running list.protected StopWatch.TaskStopWatch. getCurrentTask(boolean removed)Returns the most recently started running task, optionally removing it from the running list.static StopWatch.TaskStopWatch.Task. start(java.lang.String taskName)Creates and starts a new non-reentrant task with the given name.static StopWatch.TaskStopWatch.Task. start(java.lang.String taskName, boolean reentrant)Creates and starts a new task with the given name and reentrancy setting.Methods in io.microsphere.util that return types with arguments of type StopWatch.Task Modifier and Type Method Description java.util.List<StopWatch.Task>StopWatch. getCompletedTasks()Returns an unmodifiable list of tasks that have been completed.java.util.List<StopWatch.Task>StopWatch. getRunningTasks()Returns an unmodifiable list of tasks that are currently running.
-