Uses of Package
io.microsphere.util
-
Classes in io.microsphere.util used by io.microsphere.beans Class Description Utils A marker interface serving as a base for utility classes within the MicroSphere framework. -
Classes in io.microsphere.util used by io.microsphere.collection Class Description Utils A marker interface serving as a base for utility classes within the MicroSphere framework. -
Classes in io.microsphere.util used by io.microsphere.concurrent Class Description Utils A marker interface serving as a base for utility classes within the MicroSphere framework. -
Classes in io.microsphere.util used by io.microsphere.filter Class Description Utils A marker interface serving as a base for utility classes within the MicroSphere framework. -
Classes in io.microsphere.util used by io.microsphere.invoke Class Description Utils A marker interface serving as a base for utility classes within the MicroSphere framework. -
Classes in io.microsphere.util used by io.microsphere.io Class Description Utils A marker interface serving as a base for utility classes within the MicroSphere framework. -
Classes in io.microsphere.util used by io.microsphere.json Class Description Utils A marker interface serving as a base for utility classes within the MicroSphere framework. -
Classes in io.microsphere.util used by io.microsphere.lang Class Description Version Represents a version number composed of major, minor, and patch components. -
Classes in io.microsphere.util used by io.microsphere.management Class Description Utils A marker interface serving as a base for utility classes within the MicroSphere framework. -
Classes in io.microsphere.util used by io.microsphere.net Class Description Utils A marker interface serving as a base for utility classes within the MicroSphere framework. -
Classes in io.microsphere.util used by io.microsphere.nio.charset Class Description Utils A marker interface serving as a base for utility classes within the MicroSphere framework. -
Classes in io.microsphere.util used by io.microsphere.reflect Class Description Utils A marker interface serving as a base for utility classes within the MicroSphere framework.Version Represents a version number composed of major, minor, and patch components. -
Classes in io.microsphere.util used by io.microsphere.security Class Description Utils A marker interface serving as a base for utility classes within the MicroSphere framework. -
Classes in io.microsphere.util used by io.microsphere.text Class Description Utils A marker interface serving as a base for utility classes within the MicroSphere framework. -
Classes in io.microsphere.util used by io.microsphere.util Class Description CharSequenceComparator AComparatorimplementation for comparingCharSequenceobjects.ClassLoaderUtils.ResourceType ResourceType defines different types of resources that can be accessed through a ClassLoader.Compatible A utility class to conditionally execute logic based on version comparison.Configurer A fluent configuration utility for applying conditional operations on a value of typeT.Functional A fluent API utility class for performing chained operations on a value of typeV.PriorityComparator AComparatorimplementation that sorts objects based on the value of thePriorityannotation.PropertyResourceBundleControl AResourceBundle.Controlimplementation for loading property-based resource bundles with customizable character encoding.StopWatch.Task Represents a named task tracked by aStopWatch.TypeFinder A utility class for finding related types based on a given type.TypeFinder.Include The enumeration for the type finder includesUtils A marker interface serving as a base for utility classes within the MicroSphere framework.ValueHolder A container class to hold a mutable value of any type.Version Represents a version number composed of major, minor, and patch components.Version.Operator -
Classes in io.microsphere.util used by io.microsphere.util.jar Class Description Utils A marker interface serving as a base for utility classes within the MicroSphere framework.